<?php
namespace app\admin\controller;

use app\common\controller\Admin;

class Category extends Admin
{
    //定义表单字段与属性
    protected function fields($action='create', $data=[])
    {
        //合并初始数据
        $data = DcArrayArgs(config('form_data.admin_category_'.$action), $data);
        //所有分类字段预埋钩子
        return DcArrayArgs(config('form_fields.admin_category_'.$action), \daicuo\Category::fields($data));
    }
    
	//添加(数据库)
	public function save()
    {
        config('common.validate_name', config('validate_name.admin_category_save'));
        
        config('common.validate_scene', config('validate_scene.admin_category_save'));
        
        config('common.where_slug_unique', config('slug_unique.admin_category_save'));
        
        $term_id = \daicuo\Term::save(input('post.'));
        
		if($term_id < 1){
			$this->error(\daicuo\Term::getError());
		}
        
		$this->success(lang('success'));
	}
    
    //删除(数据库)
	public function delete()
    {
		$ids = input('id/a');
		if(!$ids){
			$this->error(lang('mustIn'));
		}
        
        \daicuo\Term::delete_ids($ids);
        
        $this->success(lang('success'));
	}
    
    //修改（表单）
	public function edit()
    {
		if( !$term_id = input('id/d',0) ){
			$this->error(lang('mustIn'));
		}
        
		//查询数据
        $data = \daicuo\Term::get_id($term_id, false);
        if( is_null($data) ){
            $this->error(lang('empty'));
        }
        
        $this->assign('query', $this->query);
        
		$this->assign('data', $data);

        $this->assign('fields', $this->formFields('edit', $data));
        
		return $this->fetch();
	}
	
	//修改（数据库）
	public function update()
    {
		$data = input('post.');
        if(!$data['term_id']){
            $this->error(lang('mustIn'));
        }
        
        config('common.validate_name', config('validate_name.admin_category_update'));
        
        config('common.validate_scene', config('validate_scene.admin_category_update'));
        
        config('common.where_slug_unique', config('slug_unique.admin_category_update'));
        
        $info = \daicuo\Term::update_id($data['term_id'], $data);
        
        if(is_null($info)){
            $this->error(\daicuo\Term::getError());
        }
        
        $this->success(lang('success'));
	}
    
    public function index()
    {
        if( $this->request->isAjax() ){
            //竖形查询
            if($this->query['sortName'] == 'tree' && $this->query['searchText']==''){
                if( count($this->query) < 7){
                    return $this->tree();
                }
            }
            //查询参数
            $args = array();
            $args['cache']         = false;
            $args['field']         = '*';
            $args['type']          = 'category';
            $args['limit']         = input('pageSize/d', 30);
            $args['page']          = input('pageNumber/d', 1);
            $args['sort']          = input('get.sortName/s','term_id');
            $args['sort']          = str_replace('tree', 'term_id', $args['sort']);
            $args['order']         = input('get.sortOrder/s','desc');
            $args['search']        = input('searchText/s','');
            //扩展字段生成查询参数
            $args['meta_query']    = [];
            foreach( DcArrayFilter($this->query, config('custom_fields.term_meta')) as $key=>$value ){
                if($value){
                    array_push($args['meta_query'], ['key'=>['eq',$key],'value'=>['eq',$value]]);
                }
            }
            //自定义查询条件
            if( $where = DcWhereQuery(['term_parent','term_order','term_module','term_status'], 'eq', $this->query) ){
                $args['where'] = $where;
            }
            //数据返回
            if($infos = DcTermSelect($args) ){
                return json($infos);
            }
            return json([]);
		}
        //地址栏参数
        $this->assign('query', $this->query);
        //表单筛选字段
        $this->assign('fields', $this->formFields('index', $this->query));
        //表格列字段
        $this->assign('columns', $this->tableColumns('index', $this->query));
        //加载模板
		return $this->fetch();
	}
    
    //默认层级结构显示
    private function tree()
    {
        $args = array();
        $args['cache'] = false;
        $args['sort']  = 'term_id';
        $args['order'] = 'desc';
        $args['type']  = 'category';
        //$args['ids'] = '1,2,3';
        //$args['module'] = 'index';
        //$args['name'] = '动作';
        //$args['slug'] = 'dongzuo';
        //$args['search'] = 'searchwd';
        $args['paginate'] = [
            'list_rows' =>DcEmpty($this->query['pageSize'], 30),
            'page' =>DcEmpty($this->query['pageNumber'], 1),
        ];
        $list = \daicuo\Term::tree($args);
        return json($list);
    }
}